Module sync

Module sync 

Functions

sync_and_migrate
Synchronize database schema from all registered entities, then run all pending migrations.
sync_and_migrate_group
Synchronize database schema for entities and migrations belonging to the named group only.